@@ -49,7 +49,7 @@ class tdcoa():
     secretpath = ''
     filesetpath = ''
     outputpath = ''
-    version = "0.3.2.2"
+    version = "0.3.3.2"
 
     # log settings
     logs =  []
@@ -1074,10 +1074,10 @@ class tdcoa():
                                 self.log('  folder does NOT MATCH a defined fileset name', setfolder)
                                 if self.settings['run_non_fileset_folders'].strip().lower() == 'true':
                                     self.log('  however setting: "run_non_fileset_folders" equals "true", continuing...')
-                                    _continue = False
+                                    _continue = True
                                 else:
                                     self.log('  and setting: "run_non_fileset_folders" not equal "true", skipping...')
-                                    _continue = True
+                                    _continue = False
                             else: # setfolder in self.filesets
                                 self.log('  folder MATCHES a defined fileset name', setfolder)
                                 if self.dict_active(self.systems[sysfolder]['filesets'][setfolder])==False:
@@ -1119,9 +1119,10 @@ class tdcoa():
 
 
                                         # SUBSTITUTE values for:  system-fileset override
-                                        sub_dict = self.systems[sysfolder]['filesets'][setfolder]
-                                        if self.dict_active(sub_dict, 'system-fileset overrides'):
-                                            runfiletext = self.substitute(runfiletext, sub_dict, subname='system-fileset overrides (highest priority)')
+                                        if setfolder in self.systems[sysfolder]['filesets']:
+                                            sub_dict = self.systems[sysfolder]['filesets'][setfolder]
+                                            if self.dict_active(sub_dict, 'system-fileset overrides'):
+                                                runfiletext = self.substitute(runfiletext, sub_dict, subname='system-fileset overrides (highest priority)')
 
                                         # SUBSTITUTE values for:  system-defaults
                                         sub_dict = self.systems[sysfolder]
@@ -1137,9 +1138,10 @@ class tdcoa():
                                                                       skipkeys=['host','username','password','logmech'])
 
                                         # SUBSTITUTE values for:   fileset defaults
-                                        sub_dict = self.filesets[setfolder]
-                                        if self.dict_active(sub_dict, 'fileset defaults'):
-                                            runfiletext = self.substitute(runfiletext, sub_dict, skipkeys=['files'], subname='fileset defaults (lowest priority)')
+                                        if setfolder in self.filesets:
+                                            sub_dict = self.filesets[setfolder]
+                                            if self.dict_active(sub_dict, 'fileset defaults'):
+                                                runfiletext = self.substitute(runfiletext, sub_dict, skipkeys=['files'], subname='fileset defaults (lowest priority)')
 
 
                                         # split sql file into many sql statements
@@ -1400,7 +1402,8 @@ class tdcoa():
                                                         sqlcmd['save'] = '%s.%s--%s' %(sysname, setname, coasqlfile) + '%04d' %sqlcnt + '.csv'
 
                                                     # once built, append output folder, SiteID on the front, iterative counter if duplicates
-                                                    csvfile = os.path.join(outputfo, sqlcmd['save'])
+                                                    #csvfile = os.path.join(outputfo, sqlcmd['save'])
+                                                    csvfile = os.path.join(workpath, sqlcmd['save'])
                                                     i=0
                                                     while os.path.isfile(csvfile):
                                                         i +=1
@@ -1471,16 +1474,19 @@ class tdcoa():
         if _outputpath !='':   # supplied parameter
             outputpath = _outputpath
             self.log('output folder = manual param', outputpath)
-        elif self.outputpath !='':  # local variable set
+        elif os.path.isfile(os.path.join(self.approot, '.last_run_output_path.txt')):
+            # .last_run_output_path.txt  in approot
+            with open(os.path.join(self.approot, '.last_run_output_path.txt'),'r') as fh:
+                outputpath = fh.read().strip().split('\n')[0]
+            self.log('output folder= .last_run_output_path.txt', outputpath)
+        elif self.outputpath !='':
+            # local variable set
             outputpath = self.outputpath
             self.log('output folder = class variable: coa.outputpath', outputpath)
-        else:  # .last_run_output_path.txt  in approot
-            if os.path.isfile(os.path.join(self.approot, '.last_run_output_path.txt')):
-                with open(os.path.join(self.approot, '.last_run_output_path.txt'),'r') as fh:
-                    outputpath = fh.read().strip().split('\n')[0]
-                self.log('output folder= .last_run_output_path.txt', outputpath)
-            else:
-                outputpath =''
+        else:
+            outputpath =''
+            self.log('no output path defined')
+
 
         # now that outputfo is defined, let's make sure the dir actually exists:
         if not os.path.isdir(outputpath):
